Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2376)

Unified Diff: chrome/browser/safe_browsing/client_side_detection_host.h

Issue 7538009: Send back the URL that matched the SafeBrowsing list with the CSD ping. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address Matt's comments. Created 9 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/safe_browsing/client_side_detection_host.h
diff --git a/chrome/browser/safe_browsing/client_side_detection_host.h b/chrome/browser/safe_browsing/client_side_detection_host.h
index ba9af18a0009e29d1f89a9bcc09ecd1cdf59da33..0e77f0afe90c53b4019f71cea960a58ca8b0505a 100644
--- a/chrome/browser/safe_browsing/client_side_detection_host.h
+++ b/chrome/browser/safe_browsing/client_side_detection_host.h
@@ -117,8 +117,10 @@ class ClientSideDetectionHost : public TabContentsObserver,
base::ScopedCallbackFactory<ClientSideDetectionHost> cb_factory_;
// Unique page ID of the most recent unsafe site that was loaded in this tab.
int unsafe_unique_page_id_;
+ scoped_ptr<SafeBrowsingService::UnsafeResource> unsafe_resource_;
DISALLOW_COPY_AND_ASSIGN(ClientSideDetectionHost);
};
@@ -117,8 +117,10 @@ class ClientSideDetectionHost : public TabContentsObserver,
base::ScopedCallbackFactory<ClientSideDetectionHost> cb_factory_;
- // Unique page ID of the most recent unsafe site that was loaded in this tab.
+ // Unique page ID of the most recent unsafe site that was loaded in this tab
+ // as well as the UnsafeResource.
int unsafe_unique_page_id_;

Powered by Google App Engine
This is Rietveld 408576698